==> zio-aws-servicequotas_3-5.17.154.1-sources.jar: zio/aws/servicequotas/model/ListAwsDefaultServiceQuotasRequest.scala <==
package zio.aws.servicequotas.model
import java.lang.Integer
import zio.aws.servicequotas.model.primitives.{
  MaxResults,
  NextToken,
  ServiceCode
}
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters.*
final case class ListAwsDefaultServiceQuotasRequest(
    serviceCode: ServiceCode,
    nextToken: Option[NextToken] = None,
    maxResults: Option[MaxResults] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.servicequotas.model.ListAwsDefaultServiceQuotasRequest = {
    import ListAwsDefaultServiceQuotasRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.servicequotas.model.ListAwsDefaultServiceQuotasRequest
      .builder()
      .serviceCode(ServiceCode.unwrap(serviceCode): java.lang.String)
      .optionallyWith(
        nextToken.map(value => NextToken.unwrap(value): java.lang.String)
      )(_.nextToken)
      .optionallyWith(
        maxResults.map(value => MaxResults.unwrap(value): Integer)
      )(_.maxResults)
      .build()
  }
  def asReadOnly
      : zio.aws.servicequotas.model.ListAwsDefaultServiceQuotasRequest.ReadOnly =
    zio.aws.servicequotas.model.ListAwsDefaultServiceQuotasRequest
      .wrap(buildAwsValue())
}
object ListAwsDefaultServiceQuotasRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.servicequotas.model.ListAwsDefaultServiceQuotasRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.servicequotas.model.ListAwsDefaultServiceQuotasRequest =
      zio.aws.servicequotas.model.ListAwsDefaultServiceQuotasRequest(
        serviceCode,
        nextToken.map(value => value),
        maxResults.map(value => value)
      )
    def serviceCode: ServiceCode
    def nextToken: Option[NextToken]
    def maxResults: Option[MaxResults]
    def getServiceCode: ZIO[Any, Nothing, ServiceCode] =
      ZIO.succeed(serviceCode)
    def getNextToken: ZIO[Any, AwsError, NextToken] =
      AwsError.unwrapOptionField("nextToken", nextToken)
    def getMaxResults: ZIO[Any, AwsError, MaxResults] =
      AwsError.unwrapOptionField("maxResults", maxResults)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.servicequotas.model.ListAwsDefaultServiceQuotasRequest
  ) extends zio.aws.servicequotas.model.ListAwsDefaultServiceQuotasRequest.ReadOnly {
    override val serviceCode: ServiceCode =
      zio.aws.servicequotas.model.primitives.ServiceCode(impl.serviceCode())
    override val nextToken: Option[NextToken] = scala
      .Option(impl.nextToken())
      .map(value => zio.aws.servicequotas.model.primitives.NextToken(value))
    override val maxResults: Option[MaxResults] = scala
      .Option(impl.maxResults())
      .map(value => zio.aws.servicequotas.model.primitives.MaxResults(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.servicequotas.model.ListAwsDefaultServiceQuotasRequest
  ): zio.aws.servicequotas.model.ListAwsDefaultServiceQuotasRequest.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-servicequotas_3-6.20.69.2-sources.jar: zio/aws/servicequotas/model/ListAwsDefaultServiceQuotasRequest.scala <==
package zio.aws.servicequotas.model
import zio.prelude.data.Optional
import zio.aws.core.{AwsError, BuilderHelper}
import zio.ZIO
import zio.aws.servicequotas.model.primitives.{
  MaxResults,
  NextToken,
  ServiceCode
}
import java.lang.Integer
import scala.jdk.CollectionConverters.*
final case class ListAwsDefaultServiceQuotasRequest(
    serviceCode: ServiceCode,
    nextToken: Optional[NextToken] = Optional.Absent,
    maxResults: Optional[MaxResults] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.servicequotas.model.ListAwsDefaultServiceQuotasRequest = {
    import ListAwsDefaultServiceQuotasRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.servicequotas.model.ListAwsDefaultServiceQuotasRequest
      .builder()
      .serviceCode(ServiceCode.unwrap(serviceCode): java.lang.String)
      .optionallyWith(
        nextToken.map(value => NextToken.unwrap(value): java.lang.String)
      )(_.nextToken)
      .optionallyWith(
        maxResults.map(value => MaxResults.unwrap(value): Integer)
      )(_.maxResults)
      .build()
  }
  def asReadOnly
      : zio.aws.servicequotas.model.ListAwsDefaultServiceQuotasRequest.ReadOnly =
    zio.aws.servicequotas.model.ListAwsDefaultServiceQuotasRequest
      .wrap(buildAwsValue())
}
object ListAwsDefaultServiceQuotasRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.servicequotas.model.ListAwsDefaultServiceQuotasRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.servicequotas.model.ListAwsDefaultServiceQuotasRequest =
      zio.aws.servicequotas.model.ListAwsDefaultServiceQuotasRequest(
        serviceCode,
        nextToken.map(value => value),
        maxResults.map(value => value)
      )
    def serviceCode: ServiceCode
    def nextToken: Optional[NextToken]
    def maxResults: Optional[MaxResults]
    def getServiceCode: ZIO[Any, Nothing, ServiceCode] =
      ZIO.succeed(serviceCode)
    def getNextToken: ZIO[Any, AwsError, NextToken] =
      AwsError.unwrapOptionField("nextToken", nextToken)
    def getMaxResults: ZIO[Any, AwsError, MaxResults] =
      AwsError.unwrapOptionField("maxResults", maxResults)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.servicequotas.model.ListAwsDefaultServiceQuotasRequest
  ) extends zio.aws.servicequotas.model.ListAwsDefaultServiceQuotasRequest.ReadOnly {
    override val serviceCode: ServiceCode =
      zio.aws.servicequotas.model.primitives.ServiceCode(impl.serviceCode())
    override val nextToken: Optional[NextToken] = zio.aws.core.internal
      .optionalFromNullable(impl.nextToken())
      .map(value => zio.aws.servicequotas.model.primitives.NextToken(value))
    override val maxResults: Optional[MaxResults] = zio.aws.core.internal
      .optionalFromNullable(impl.maxResults())
      .map(value => zio.aws.servicequotas.model.primitives.MaxResults(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.servicequotas.model.ListAwsDefaultServiceQuotasRequest
  ): zio.aws.servicequotas.model.ListAwsDefaultServiceQuotasRequest.ReadOnly =
    new Wrapper(impl)
}
